c.size <-function (...)
{
  .Deprecated("cSize", package="Morpho")
  cSize(...)
}
c.extract <-function (...)
{
  .Deprecated("cExtract", package="Morpho")
  cSize(...)
}
mc.procSym <-function (...)
{
  .Deprecated("procSym", package="Morpho")
  procSym(...)
}
mc.slider3d <-function (...)
{
  .Deprecated("slider3d", package="Morpho")
  slider3d(...)
}
mc.CVA <-function (...)
{
  .Deprecated("CVA", package="Morpho")
  CVA(...)
}
deform.grid <-function (...)
{
  .Deprecated("deformGrid3d", package="Morpho")
  deformGrid3d(...)
}
regdist.raw <-function (...)
{
  .Deprecated("regdist", package="Morpho")
  regdist(...)
}
